# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/service_provider_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import peer_pb2 as avikom_dot_generic_dot_peer__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.assistance import service_configuration_pb2 as avikom_dot_assistance_dot_service__configuration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0avikom/assistance/service_provider_service.proto\x12\x11\x61vikom.assistance\x1a\x19\x61vikom/generic/peer.proto\x1a\x1b\x61vikom/generic/result.proto\x1a-avikom/assistance/service_configuration.proto\"\x86\x01\n\x0eServiceRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12>\n\rconfiguration\x18\x02 \x01(\x0b\x32\'.avikom.assistance.ServiceConfiguration\x12#\n\x05peers\x18\x03 \x03(\x0b\x32\x14.avikom.generic.Peer2\xc0\x01\n\x16ServiceProviderService\x12Q\n\x12PostServiceRequest\x12!.avikom.assistance.ServiceRequest\x1a\x16.avikom.generic.Result\"\x00\x12S\n\x14\x43\x61ncelServiceRequest\x12!.avikom.assistance.ServiceRequest\x1a\x16.avikom.generic.Result\"\x00\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.service_provider_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _SERVICEREQUEST._serialized_start=175
  _SERVICEREQUEST._serialized_end=309
  _SERVICEPROVIDERSERVICE._serialized_start=312
  _SERVICEPROVIDERSERVICE._serialized_end=504
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/tunnel/client_to_server.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import peer_pb2 as avikom_dot_generic_dot_peer__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$avikom/tunnel/client_to_server.proto\x12\ravikom.tunnel\x1a\x19\x61vikom/generic/peer.proto\"Z\n\x0e\x43lientToServer\x12\x10\n\x08response\x18\x01 \x01(\x0c\x12\x12\n\nmessage_id\x18\x02 \x01(\x04\x12\"\n\x04peer\x18\x03 \x01(\x0b\x32\x14.avikom.generic.PeerBi\n\x17\x61pp.avikom.types.tunnelZ8gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/tunnel\xaa\x02\x13\x41vikom.Types.Tunnelb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.tunnel.client_to_server_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027app.avikom.types.tunnelZ8gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/tunnel\252\002\023Avikom.Types.Tunnel'
  _CLIENTTOSERVER._serialized_start=82
  _CLIENTTOSERVER._serialized_end=172
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class InteractionEventQuery(google.protobuf.message.Message):
    """*
    This message is DEPRECATED; This message is used to query user interaction events of a particular session. 
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_ID_FIELD_NUMBER: builtins.int
    session_id: builtins.str
    """id of the requested session"""
    def __init__(
        self,
        *,
        session_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["session_id", b"session_id"]) -> None: ...

global___InteractionEventQuery = InteractionEventQuery



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class KeyValuePair(google.protobuf.message.Message):
    """*
    This message is used to transfer associated information (i.e. slots extracted by rasa). 
    @author Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: builtins.str
    """/ defines the value data type; informs consumer how to parse value"""
    value: builtins.str
    """/ value holds information serialized as string and needs to be parsed by consumer"""
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

global___KeyValuePair = KeyValuePair



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.math.vector3d_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Transpose(google.protobuf.message.Message):
    """*
    This message describes a 3D world pose of an object/entity.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POSITION_FIELD_NUMBER: builtins.int
    ROTATION_FIELD_NUMBER: builtins.int
    SCALE_FIELD_NUMBER: builtins.int
    @property
    def position(self) -> avikom.math.vector3d_pb2.Vector3D:
        """/ position in world units (meters) of the entity"""
    @property
    def rotation(self) -> avikom.math.vector3d_pb2.Vector3D:
        """/ rotation in euler angles (degrees)"""
    @property
    def scale(self) -> avikom.math.vector3d_pb2.Vector3D:
        """/ three dimensional scaling factor"""
    def __init__(
        self,
        *,
        position: avikom.math.vector3d_pb2.Vector3D | None = ...,
        rotation: avikom.math.vector3d_pb2.Vector3D | None = ...,
        scale: avikom.math.vector3d_pb2.Vector3D | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["position", b"position", "rotation", b"rotation", "scale", b"scale"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["position", b"position", "rotation", b"rotation", "scale", b"scale"]) -> None: ...

global___Transpose = Transpose



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/scene.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.options import options_pb2 as avikom_dot_options_dot_options__pb2
from avikom.assistance import task_pb2 as avikom_dot_assistance_dot_task__pb2
from avikom.unity import game_object_pb2 as avikom_dot_unity_dot_game__object__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61vikom/assistance/scene.proto\x12\x11\x61vikom.assistance\x1a\x1c\x61vikom/options/options.proto\x1a\x1c\x61vikom/assistance/task.proto\x1a\x1e\x61vikom/unity/game_object.proto\"K\n\x05Scene\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\x8a\xb5\x18\x02\x10\x01\x12&\n\x05tasks\x18\x02 \x03(\x0b\x32\x17.avikom.assistance.Task:\x04\x88\xb5\x18\x01\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.scene_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _SCENE.fields_by_name['name']._options = None
  _SCENE.fields_by_name['name']._serialized_options = b'\212\265\030\002\020\001'
  _SCENE._options = None
  _SCENE._serialized_options = b'\210\265\030\001'
  _SCENE._serialized_start=144
  _SCENE._serialized_end=219
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.assistance import split_procedure_result_pb2 as avikom_dot_assistance_dot_split__procedure__result__pb2
from avikom.assistance import step_proficiency_pb2 as avikom_dot_assistance_dot_step__proficiency__pb2
from avikom.assistance import step_proficiency_storage_service_pb2 as avikom_dot_assistance_dot_step__proficiency__storage__service__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2


class StepProficiencyStorageServiceStub(object):
    """
    Stores the required step proficiencies for users and their split procedure results.
    If no record exists for user_id, Get/SetStepProficiency should generate and/or work with
    default data and information retrieved from task step stereotypes. Thus there should always be
    a valid return value and/or generated entry to work with. Furthermore,
    assistance_decay should be 'fuzzy' to follow ideas presented in https://www.mdpi.com/2078-2489/12/1/17. 
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetStepProficiency = channel.unary_unary(
                '/avikom.assistance.StepProficiencyStorageService/GetStepProficiency',
                request_serializer=avikom_dot_assistance_dot_step__proficiency__storage__service__pb2.StepProficiencyQuery.SerializeToString,
                response_deserializer=avikom_dot_assistance_dot_step__proficiency__pb2.StepProficiency.FromString,
                )
        self.SetStepProficiency = channel.unary_unary(
                '/avikom.assistance.StepProficiencyStorageService/SetStepProficiency',
                request_serializer=avikom_dot_assistance_dot_step__proficiency__pb2.StepProficiency.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.GetSplitProcedureResult = channel.unary_unary(
                '/avikom.assistance.StepProficiencyStorageService/GetSplitProcedureResult',
                request_serializer=avikom_dot_assistance_dot_step__proficiency__storage__service__pb2.StepProficiencyQuery.SerializeToString,
                response_deserializer=avikom_dot_assistance_dot_split__procedure__result__pb2.SplitProcedureResult.FromString,
                )
        self.SetSplitProcedureResult = channel.unary_unary(
                '/avikom.assistance.StepProficiencyStorageService/SetSplitProcedureResult',
                request_serializer=avikom_dot_assistance_dot_split__procedure__result__pb2.SplitProcedureResult.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )


class StepProficiencyStorageServiceServicer(object):
    """
    Stores the required step proficiencies for users and their split procedure results.
    If no record exists for user_id, Get/SetStepProficiency should generate and/or work with
    default data and information retrieved from task step stereotypes. Thus there should always be
    a valid return value and/or generated entry to work with. Furthermore,
    assistance_decay should be 'fuzzy' to follow ideas presented in https://www.mdpi.com/2078-2489/12/1/17. 
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def GetStepProficiency(self, request, context):
        """/ returns step proficiency for a user with `user_id` and the task step named `target_name` 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetStepProficiency(self, request, context):
        """/ updates or creates the step proficiency for a user with `user_id` for the task step named `target_name`
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSplitProcedureResult(self, request, context):
        """/ returns the split procedure results for a user with `user_id` for the task named `target_name`  
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetSplitProcedureResult(self, request, context):
        """/ creates or updates split procedure results for a user with `user_id` for the task named `target_name`  
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StepProficiencyStorageServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetStepProficiency': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStepProficiency,
                    request_deserializer=avikom_dot_assistance_dot_step__proficiency__storage__service__pb2.StepProficiencyQuery.FromString,
                    response_serializer=avikom_dot_assistance_dot_step__proficiency__pb2.StepProficiency.SerializeToString,
            ),
            'SetStepProficiency': grpc.unary_unary_rpc_method_handler(
                    servicer.SetStepProficiency,
                    request_deserializer=avikom_dot_assistance_dot_step__proficiency__pb2.StepProficiency.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'GetSplitProcedureResult': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSplitProcedureResult,
                    request_deserializer=avikom_dot_assistance_dot_step__proficiency__storage__service__pb2.StepProficiencyQuery.FromString,
                    response_serializer=avikom_dot_assistance_dot_split__procedure__result__pb2.SplitProcedureResult.SerializeToString,
            ),
            'SetSplitProcedureResult': grpc.unary_unary_rpc_method_handler(
                    servicer.SetSplitProcedureResult,
                    request_deserializer=avikom_dot_assistance_dot_split__procedure__result__pb2.SplitProcedureResult.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.assistance.StepProficiencyStorageService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StepProficiencyStorageService(object):
    """
    Stores the required step proficiencies for users and their split procedure results.
    If no record exists for user_id, Get/SetStepProficiency should generate and/or work with
    default data and information retrieved from task step stereotypes. Thus there should always be
    a valid return value and/or generated entry to work with. Furthermore,
    assistance_decay should be 'fuzzy' to follow ideas presented in https://www.mdpi.com/2078-2489/12/1/17. 
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    @staticmethod
    def GetStepProficiency(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.StepProficiencyStorageService/GetStepProficiency',
            avikom_dot_assistance_dot_step__proficiency__storage__service__pb2.StepProficiencyQuery.SerializeToString,
            avikom_dot_assistance_dot_step__proficiency__pb2.StepProficiency.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetStepProficiency(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.StepProficiencyStorageService/SetStepProficiency',
            avikom_dot_assistance_dot_step__proficiency__pb2.StepProficiency.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSplitProcedureResult(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.StepProficiencyStorageService/GetSplitProcedureResult',
            avikom_dot_assistance_dot_step__proficiency__storage__service__pb2.StepProficiencyQuery.SerializeToString,
            avikom_dot_assistance_dot_split__procedure__result__pb2.SplitProcedureResult.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetSplitProcedureResult(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.StepProficiencyStorageService/SetSplitProcedureResult',
            avikom_dot_assistance_dot_split__procedure__result__pb2.SplitProcedureResult.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _LogLevel:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LogLevelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LogLevel.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEBUG: _LogLevel.ValueType  # 0
    """/ default level used for debugging"""
    INFO: _LogLevel.ValueType  # 1
    """/ information that might be of interest to developers also during production"""
    WARN: _LogLevel.ValueType  # 2
    """/ warnings that should be of interest to developers and can foreshadow future errors"""
    ERROR: _LogLevel.ValueType  # 3
    """/ errors that are of interest to developers and break functionality"""
    FATAL: _LogLevel.ValueType  # 4
    """/ erros that result in total or partial system failure"""

class LogLevel(_LogLevel, metaclass=_LogLevelEnumTypeWrapper):
    """
    The LogLevel specifies the criticality of a log
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

DEBUG: LogLevel.ValueType  # 0
"""/ default level used for debugging"""
INFO: LogLevel.ValueType  # 1
"""/ information that might be of interest to developers also during production"""
WARN: LogLevel.ValueType  # 2
"""/ warnings that should be of interest to developers and can foreshadow future errors"""
ERROR: LogLevel.ValueType  # 3
"""/ errors that are of interest to developers and break functionality"""
FATAL: LogLevel.ValueType  # 4
"""/ erros that result in total or partial system failure"""
global___LogLevel = LogLevel

@typing_extensions.final
class Message(google.protobuf.message.Message):
    """
    A message specifying the log combining the log level, the logging message and the origin
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LEVEL_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    ORIGIN_FIELD_NUMBER: builtins.int
    level: global___LogLevel.ValueType
    """/ holds the log level of the message"""
    content: builtins.str
    """/ holds the log message"""
    origin: builtins.str
    """/ which service issued the log"""
    def __init__(
        self,
        *,
        level: global___LogLevel.ValueType = ...,
        content: builtins.str = ...,
        origin: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "level", b"level", "origin", b"origin"]) -> None: ...

global___Message = Message



from setuptools import setup, find_packages
import os
import codecs
from os.path import join

project_root = os.path.dirname(os.path.abspath(__file__))
packages = find_packages(exclude="test")

version = {}
REQUIRED_EXTRAS = {}
with open(join(project_root, "avikom_types/version.py")) as read_file:
    exec(read_file.read(), version)

with open(join(project_root, "requirements.txt")) as read_file:
    REQUIRED = []
    for req in read_file.read().splitlines():
        if req.startswith("git+"):
            package = req.split("egg=")[1]
            req = f"{package} @ {req}"
        elif req.startswith("#"):
            continue
        REQUIRED.append(req)

# print("REQ:", REQUIRED)
with codecs.open(join(project_root, "README.md"), "r", "utf-8") as f:
    long_description = "".join(f.readlines())

setup(
    name="avikom-types",
    version=version["__version__"],
    description="Avikom Protocol Buffer Types",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=packages,
    package_data={package: ["py.typed", "*.pyi"] for package in packages},
    zip_safe=False,
    install_requires=REQUIRED,
    author="Alexander Neumann",
    author_email="alneuman@techfak.uni-bielefeld.de",
    keywords=["avikom, protocol buffers"],
    url="https://gitlab.ub.uni-bielefeld.de/avikom/converter",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Development Status :: 4 - Beta",
    ],
)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AssistanceLevel:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AssistanceLevelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AssistanceLevel.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _AssistanceLevel.ValueType  # 0
    """/ representes an unset level; should not be used explicitely"""
    NONE: _AssistanceLevel.ValueType  # 1
    """/ user requires no assistance; instructions assigned to this level are considered mandatory"""
    BRIEF: _AssistanceLevel.ValueType  # 2
    """/ provides some (textual/visual) hooks to remember the step at hand"""
    DEFAULT: _AssistanceLevel.ValueType  # 5
    """/ this should be the experience for new and unknown users"""
    VERBOSE: _AssistanceLevel.ValueType  # 9
    """/ highest demand for assistance; should provide all assistance possible"""

class AssistanceLevel(_AssistanceLevel, metaclass=_AssistanceLevelEnumTypeWrapper):
    """*
    This enum describes the assistance level required by a user or assigned to an instruction.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

UNKNOWN: AssistanceLevel.ValueType  # 0
"""/ representes an unset level; should not be used explicitely"""
NONE: AssistanceLevel.ValueType  # 1
"""/ user requires no assistance; instructions assigned to this level are considered mandatory"""
BRIEF: AssistanceLevel.ValueType  # 2
"""/ provides some (textual/visual) hooks to remember the step at hand"""
DEFAULT: AssistanceLevel.ValueType  # 5
"""/ this should be the experience for new and unknown users"""
VERBOSE: AssistanceLevel.ValueType  # 9
"""/ highest demand for assistance; should provide all assistance possible"""
global___AssistanceLevel = AssistanceLevel



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/issue_query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import issue_pb2 as avikom_dot_assistance_dot_issue__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#avikom/assistance/issue_query.proto\x12\x11\x61vikom.assistance\x1a\x1d\x61vikom/assistance/issue.proto\"Y\n\nIssueQuery\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\x06status\x18\x02 \x01(\x0e\x32\x1e.avikom.assistance.IssueStatus\x12\x0f\n\x07user_id\x18\x03 \x01(\x04\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.issue_query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _ISSUEQUERY._serialized_start=89
  _ISSUEQUERY._serialized_end=178
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.assistance.instruction_meta_pb2
import avikom.assistance.instruction_text_value_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ContentStyle:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ContentStyleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ContentStyle.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    STYLE_UNKNOWN: _ContentStyle.ValueType  # 0
    """/ no content info available"""
    STYLE_INFO: _ContentStyle.ValueType  # 1
    """/ used for default instructions"""
    STYLE_WARNING: _ContentStyle.ValueType  # 2
    """/ used when caution is advises"""
    STYLE_CRITICAL: _ContentStyle.ValueType  # 3
    """/ used when extreme caution is advises"""
    STYLE_SUCESS: _ContentStyle.ValueType  # 4
    """/ a positive success message"""
    STYLE_ERROR: _ContentStyle.ValueType  # 5
    """/ used for reporting errors"""

class ContentStyle(_ContentStyle, metaclass=_ContentStyleEnumTypeWrapper):
    """*
    Defines the content style of a textual instruction. This should be used to transport contextual semantics such as urgency.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

STYLE_UNKNOWN: ContentStyle.ValueType  # 0
"""/ no content info available"""
STYLE_INFO: ContentStyle.ValueType  # 1
"""/ used for default instructions"""
STYLE_WARNING: ContentStyle.ValueType  # 2
"""/ used when caution is advises"""
STYLE_CRITICAL: ContentStyle.ValueType  # 3
"""/ used when extreme caution is advises"""
STYLE_SUCESS: ContentStyle.ValueType  # 4
"""/ a positive success message"""
STYLE_ERROR: ContentStyle.ValueType  # 5
"""/ used for reporting errors"""
global___ContentStyle = ContentStyle

@typing_extensions.final
class InstructionText(google.protobuf.message.Message):
    """*
    This message should be used for textual instruction that can be displayed or spoken.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    META_FIELD_NUMBER: builtins.int
    CONTENT_STYLE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    PREVIEW_FIELD_NUMBER: builtins.int
    @property
    def meta(self) -> avikom.assistance.instruction_meta_pb2.InstructionMeta:
        """/ context information for the instruction"""
    content_style: global___ContentStyle.ValueType
    """/ styling hints for the text instruction"""
    @property
    def content(self) -> avikom.assistance.instruction_text_value_pb2.InstructionTextValue:
        """/ the runtime value of an instruction, can include moustache fields"""
    @property
    def preview(self) -> avikom.assistance.instruction_text_value_pb2.InstructionTextValue:
        """/ optional field which will be shown during step preview; must not contain dynamic content"""
    def __init__(
        self,
        *,
        meta: avikom.assistance.instruction_meta_pb2.InstructionMeta | None = ...,
        content_style: global___ContentStyle.ValueType = ...,
        content: avikom.assistance.instruction_text_value_pb2.InstructionTextValue | None = ...,
        preview: avikom.assistance.instruction_text_value_pb2.InstructionTextValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content", b"content", "meta", b"meta", "preview", b"preview"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "content_style", b"content_style", "meta", b"meta", "preview", b"preview"]) -> None: ...

global___InstructionText = InstructionText



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/session_storage_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.options import options_pb2 as avikom_dot_options_dot_options__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.assistance import session_pb2 as avikom_dot_assistance_dot_session__pb2
from avikom.assistance import session_query_pb2 as avikom_dot_assistance_dot_session__query__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/avikom/assistance/session_storage_service.proto\x12\x11\x61vikom.assistance\x1a\x1c\x61vikom/options/options.proto\x1a\x1b\x61vikom/generic/result.proto\x1a\x1f\x61vikom/assistance/session.proto\x1a%avikom/assistance/session_query.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\";\n\x0bSessionList\x12,\n\x08sessions\x18\x01 \x03(\x0b\x32\x1a.avikom.assistance.Session2\x9f\x03\n\x15SessionStorageService\x12\x43\n\x0bSaveSession\x12\x1a.avikom.assistance.Session\x1a\x16.avikom.generic.Result\"\x00\x12l\n\nGetSession\x12\x1f.avikom.assistance.SessionQuery\x1a\x1a.avikom.assistance.Session\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/storage/sessions/{id}\x12\x66\n\x0eGetAllSessions\x12\x16.google.protobuf.Empty\x1a\x1e.avikom.assistance.SessionList\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/storage/sessions\x12k\n\rDeleteSession\x12\x1f.avikom.assistance.SessionQuery\x1a\x16.avikom.generic.Result\"!\x82\xd3\xe4\x93\x02\x1b*\x19/v1/storage/sessions/{id}Bu\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.session_storage_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _SESSIONSTORAGESERVICE.methods_by_name['GetSession']._options = None
  _SESSIONSTORAGESERVICE.methods_by_name['GetSession']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/storage/sessions/{id}'
  _SESSIONSTORAGESERVICE.methods_by_name['GetAllSessions']._options = None
  _SESSIONSTORAGESERVICE.methods_by_name['GetAllSessions']._serialized_options = b'\202\323\344\223\002\026\022\024/v1/storage/sessions'
  _SESSIONSTORAGESERVICE.methods_by_name['DeleteSession']._options = None
  _SESSIONSTORAGESERVICE.methods_by_name['DeleteSession']._serialized_options = b'\202\323\344\223\002\033*\031/v1/storage/sessions/{id}'
  _SESSIONLIST._serialized_start=260
  _SESSIONLIST._serialized_end=319
  _SESSIONSTORAGESERVICE._serialized_start=322
  _SESSIONSTORAGESERVICE._serialized_end=737
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class RasaQuery(google.protobuf.message.Message):
    """*
    A query passed to RasaService
    @author Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.int
    """/ the id of the user for which information shall be queried"""
    def __init__(
        self,
        *,
        user_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["user_id", b"user_id"]) -> None: ...

global___RasaQuery = RasaQuery

@typing_extensions.final
class RasaResult(google.protobuf.message.Message):
    """*
    A list containing intents.
    @author Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTENTS_FIELD_NUMBER: builtins.int
    @property
    def intents(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """/ a list of intents that can be used to resolve task steps"""
    def __init__(
        self,
        *,
        intents: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["intents", b"intents"]) -> None: ...

global___RasaResult = RasaResult



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.assistance import runtime_step_list_pb2 as avikom_dot_assistance_dot_runtime__step__list__pb2
from avikom.assistance import session_query_pb2 as avikom_dot_assistance_dot_session__query__pb2
from avikom.assistance import session_service_pb2 as avikom_dot_assistance_dot_session__service__pb2
from avikom.generic import peer_pb2 as avikom_dot_generic_dot_peer__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class SessionServiceStub(object):
    """
    This service initializes sessions and starts the related Camunda processes.
    It also processes TaskStep completion and failure events and forwards these information to Camunda.
    Furthermore it processes environmental factors that may influence a session and can be used to request currently eligible `RuntimeTaskSteps`.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.EmitEvent = channel.unary_unary(
                '/avikom.assistance.SessionService/EmitEvent',
                request_serializer=avikom_dot_assistance_dot_session__service__pb2.SessionEvent.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.CompleteTaskStep = channel.unary_unary(
                '/avikom.assistance.SessionService/CompleteTaskStep',
                request_serializer=avikom_dot_assistance_dot_session__service__pb2.TaskEvent.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.FailTaskStep = channel.unary_unary(
                '/avikom.assistance.SessionService/FailTaskStep',
                request_serializer=avikom_dot_assistance_dot_session__service__pb2.TaskEvent.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.GetCurrentStep = channel.unary_unary(
                '/avikom.assistance.SessionService/GetCurrentStep',
                request_serializer=avikom_dot_assistance_dot_session__query__pb2.SessionQuery.SerializeToString,
                response_deserializer=avikom_dot_assistance_dot_runtime__step__list__pb2.RuntimeStepList.FromString,
                )
        self.StartSession = channel.unary_unary(
                '/avikom.assistance.SessionService/StartSession',
                request_serializer=avikom_dot_assistance_dot_session__query__pb2.SessionQuery.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.SuspendSession = channel.unary_unary(
                '/avikom.assistance.SessionService/SuspendSession',
                request_serializer=avikom_dot_assistance_dot_session__query__pb2.SessionQuery.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.EndSession = channel.unary_unary(
                '/avikom.assistance.SessionService/EndSession',
                request_serializer=avikom_dot_assistance_dot_session__query__pb2.SessionQuery.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.UpdateEnvironmentalFactors = channel.unary_unary(
                '/avikom.assistance.SessionService/UpdateEnvironmentalFactors',
                request_serializer=avikom_dot_assistance_dot_session__service__pb2.EnvironmentalFactorsUpdate.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.RegisterUserPeer = channel.unary_unary(
                '/avikom.assistance.SessionService/RegisterUserPeer',
                request_serializer=avikom_dot_generic_dot_peer__pb2.Peer.SerializeToString,
                response_deserializer=avikom_dot_assistance_dot_runtime__step__list__pb2.RuntimeStepList.FromString,
                )
        self.EndAllProcesses = channel.unary_unary(
                '/avikom.assistance.SessionService/EndAllProcesses',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )


class SessionServiceServicer(object):
    """
    This service initializes sessions and starts the related Camunda processes.
    It also processes TaskStep completion and failure events and forwards these information to Camunda.
    Furthermore it processes environmental factors that may influence a session and can be used to request currently eligible `RuntimeTaskSteps`.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def EmitEvent(self, request, context):
        """/ pushes an event to Camunda for processing
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CompleteTaskStep(self, request, context):
        """/ completes an event; `task_id` is required; `result` will be forwarded to the related service worker if provided.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FailTaskStep(self, request, context):
        """/ fails an event; `task_id` is required; This will most likely lead to Camunda advertising the related `TaskStep` again or process failure if the maximum amount of retries has been reached.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCurrentStep(self, request, context):
        """/ returns the currently eligible `RunTimeTaskSteps` assigned to a session
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartSession(self, request, context):
        """/ starts a session; a mean to identify the user (e.g. `user_id` or `username`) must be provided
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SuspendSession(self, request, context):
        """/ suspends a session; it can be continued later on; can be queried with `session_id` or means to identify the user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EndSession(self, request, context):
        """/ removes the session from the system; can be queried with `session_id` or means to identify the user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEnvironmentalFactors(self, request, context):
        """/ updates `brightness` and/or `volume` (loudness) of a session; with only a scene name passed, all related sessions should be updated
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterUserPeer(self, request, context):
        """/ Registers or updates a peer of a user for a running session. The new peer receives the currently processed and orchestrated RuntimeStepList.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EndAllProcesses(self, request, context):
        """/ Ends all sessions and all Camunda processes
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SessionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'EmitEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.EmitEvent,
                    request_deserializer=avikom_dot_assistance_dot_session__service__pb2.SessionEvent.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'CompleteTaskStep': grpc.unary_unary_rpc_method_handler(
                    servicer.CompleteTaskStep,
                    request_deserializer=avikom_dot_assistance_dot_session__service__pb2.TaskEvent.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'FailTaskStep': grpc.unary_unary_rpc_method_handler(
                    servicer.FailTaskStep,
                    request_deserializer=avikom_dot_assistance_dot_session__service__pb2.TaskEvent.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'GetCurrentStep': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCurrentStep,
                    request_deserializer=avikom_dot_assistance_dot_session__query__pb2.SessionQuery.FromString,
                    response_serializer=avikom_dot_assistance_dot_runtime__step__list__pb2.RuntimeStepList.SerializeToString,
            ),
            'StartSession': grpc.unary_unary_rpc_method_handler(
                    servicer.StartSession,
                    request_deserializer=avikom_dot_assistance_dot_session__query__pb2.SessionQuery.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'SuspendSession': grpc.unary_unary_rpc_method_handler(
                    servicer.SuspendSession,
                    request_deserializer=avikom_dot_assistance_dot_session__query__pb2.SessionQuery.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'EndSession': grpc.unary_unary_rpc_method_handler(
                    servicer.EndSession,
                    request_deserializer=avikom_dot_assistance_dot_session__query__pb2.SessionQuery.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'UpdateEnvironmentalFactors': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEnvironmentalFactors,
                    request_deserializer=avikom_dot_assistance_dot_session__service__pb2.EnvironmentalFactorsUpdate.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'RegisterUserPeer': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterUserPeer,
                    request_deserializer=avikom_dot_generic_dot_peer__pb2.Peer.FromString,
                    response_serializer=avikom_dot_assistance_dot_runtime__step__list__pb2.RuntimeStepList.SerializeToString,
            ),
            'EndAllProcesses': grpc.unary_unary_rpc_method_handler(
                    servicer.EndAllProcesses,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.assistance.SessionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SessionService(object):
    """
    This service initializes sessions and starts the related Camunda processes.
    It also processes TaskStep completion and failure events and forwards these information to Camunda.
    Furthermore it processes environmental factors that may influence a session and can be used to request currently eligible `RuntimeTaskSteps`.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    @staticmethod
    def EmitEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.SessionService/EmitEvent',
            avikom_dot_assistance_dot_session__service__pb2.SessionEvent.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CompleteTaskStep(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.SessionService/CompleteTaskStep',
            avikom_dot_assistance_dot_session__service__pb2.TaskEvent.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FailTaskStep(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.SessionService/FailTaskStep',
            avikom_dot_assistance_dot_session__service__pb2.TaskEvent.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCurrentStep(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.SessionService/GetCurrentStep',
            avikom_dot_assistance_dot_session__query__pb2.SessionQuery.SerializeToString,
            avikom_dot_assistance_dot_runtime__step__list__pb2.RuntimeStepList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.SessionService/StartSession',
            avikom_dot_assistance_dot_session__query__pb2.SessionQuery.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SuspendSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.SessionService/SuspendSession',
            avikom_dot_assistance_dot_session__query__pb2.SessionQuery.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EndSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.SessionService/EndSession',
            avikom_dot_assistance_dot_session__query__pb2.SessionQuery.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEnvironmentalFactors(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.SessionService/UpdateEnvironmentalFactors',
            avikom_dot_assistance_dot_session__service__pb2.EnvironmentalFactorsUpdate.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterUserPeer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.SessionService/RegisterUserPeer',
            avikom_dot_generic_dot_peer__pb2.Peer.SerializeToString,
            avikom_dot_assistance_dot_runtime__step__list__pb2.RuntimeStepList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EndAllProcesses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.SessionService/EndAllProcesses',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/step_proficiency.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.options import options_pb2 as avikom_dot_options_dot_options__pb2
from avikom.assistance import task_step_pb2 as avikom_dot_assistance_dot_task__step__pb2
from avikom.generic import user_pb2 as avikom_dot_generic_dot_user__pb2
from avikom.assistance import assistance_level_pb2 as avikom_dot_assistance_dot_assistance__level__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(avikom/assistance/step_proficiency.proto\x12\x11\x61vikom.assistance\x1a\x1c\x61vikom/options/options.proto\x1a!avikom/assistance/task_step.proto\x1a\x19\x61vikom/generic/user.proto\x1a(avikom/assistance/assistance_level.proto\"\x96\x02\n\x0fStepProficiency\x12?\n\x13required_assistance\x18\x01 \x01(\x0e\x32\".avikom.assistance.AssistanceLevel\x12\"\n\x04user\x18\x02 \x01(\x0b\x32\x14.avikom.generic.User\x12)\n\x04step\x18\x03 \x01(\x0b\x32\x1b.avikom.assistance.TaskStep\x12\x10\n\x08tendency\x18\x04 \x01(\x02\x12\x1b\n\x13\x61ssistance_decrease\x18\x05 \x01(\x02\x12>\n\x12minimal_assistance\x18\x06 \x01(\x0e\x32\".avikom.assistance.AssistanceLevel:\x04\x88\xb5\x18\x01\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.step_proficiency_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _STEPPROFICIENCY._options = None
  _STEPPROFICIENCY._serialized_options = b'\210\265\030\001'
  _STEPPROFICIENCY._serialized_start=198
  _STEPPROFICIENCY._serialized_end=476
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/generic/peer_storage_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import peer_pb2 as avikom_dot_generic_dot_peer__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.generic import user_pb2 as avikom_dot_generic_dot_user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)avikom/generic/peer_storage_service.proto\x12\x0e\x61vikom.generic\x1a\x19\x61vikom/generic/peer.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1b\x61vikom/generic/result.proto\x1a\x19\x61vikom/generic/user.proto\" \n\x10PeerStorageQuery\x12\x0c\n\x04name\x18\x01 \x01(\t2\xd3\x03\n\x12PeerStorageService\x12t\n\nUpdatePeer\x12\x14.avikom.generic.Peer\x1a\x16.avikom.generic.Result\"8\x82\xd3\xe4\x93\x02\x32\x32\x11/v1/storage/peers:\x01*Z\x1a\x32\x18/v1/storage/peers/{name}\x12\x63\n\x07GetPeer\x12 .avikom.generic.PeerStorageQuery\x1a\x14.avikom.generic.Peer\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/storage/peers/{name}\x12\x63\n\x0cGetUserPeers\x12\x14.avikom.generic.User\x1a\x18.avikom.generic.PeerList\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/storage/peers/user/{id}\x12}\n\nDeletePeer\x12 .avikom.generic.PeerStorageQuery\x1a\x16.avikom.generic.Result\"5\x82\xd3\xe4\x93\x02/*\x11/v1/storage/peersZ\x1a*\x18/v1/storage/peers/{name}Bl\n\x18\x61pp.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\xaa\x02\x14\x41vikom.Types.Genericb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.generic.peer_storage_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\252\002\024Avikom.Types.Generic'
  _PEERSTORAGESERVICE.methods_by_name['UpdatePeer']._options = None
  _PEERSTORAGESERVICE.methods_by_name['UpdatePeer']._serialized_options = b'\202\323\344\223\00222\021/v1/storage/peers:\001*Z\0322\030/v1/storage/peers/{name}'
  _PEERSTORAGESERVICE.methods_by_name['GetPeer']._options = None
  _PEERSTORAGESERVICE.methods_by_name['GetPeer']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/storage/peers/{name}'
  _PEERSTORAGESERVICE.methods_by_name['GetUserPeers']._options = None
  _PEERSTORAGESERVICE.methods_by_name['GetUserPeers']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/storage/peers/user/{id}'
  _PEERSTORAGESERVICE.methods_by_name['DeletePeer']._options = None
  _PEERSTORAGESERVICE.methods_by_name['DeletePeer']._serialized_options = b'\202\323\344\223\002/*\021/v1/storage/peersZ\032*\030/v1/storage/peers/{name}'
  _PEERSTORAGEQUERY._serialized_start=174
  _PEERSTORAGEQUERY._serialized_end=206
  _PEERSTORAGESERVICE._serialized_start=209
  _PEERSTORAGESERVICE._serialized_end=676
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AssetBundleQuery(google.protobuf.message.Message):
    """
    A message to request asset bundles from a server.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUNDLE_NAME_FIELD_NUMBER: builtins.int
    bundle_name: builtins.str
    """/ globally unique name of the bundle"""
    def __init__(
        self,
        *,
        bundle_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bundle_name", b"bundle_name"]) -> None: ...

global___AssetBundleQuery = AssetBundleQuery



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.nlp import answer_question_service_pb2 as avikom_dot_nlp_dot_answer__question__service__pb2


class AnswerQuestionServiceStub(object):
    """*
    This service sends a question and context as requests to the nlp module (currently HuggingFace).
    For example, you might want to extract information from a text by asking a question. You assume, that 
    the answer to your question can be found within the text.
    @author: Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AnswerQuestion = channel.unary_unary(
                '/avikom.nlp.AnswerQuestionService/AnswerQuestion',
                request_serializer=avikom_dot_nlp_dot_answer__question__service__pb2.AnswerQuestionQuery.SerializeToString,
                response_deserializer=avikom_dot_nlp_dot_answer__question__service__pb2.AnswerQuestionResponse.FromString,
                )


class AnswerQuestionServiceServicer(object):
    """*
    This service sends a question and context as requests to the nlp module (currently HuggingFace).
    For example, you might want to extract information from a text by asking a question. You assume, that 
    the answer to your question can be found within the text.
    @author: Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

    def AnswerQuestion(self, request, context):
        """/ the answer to the posed question is searched in the set context and returned if found; 
        / the model is currently based on https://huggingface.co/Sahajtomar/GBERTQnA
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AnswerQuestionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AnswerQuestion': grpc.unary_unary_rpc_method_handler(
                    servicer.AnswerQuestion,
                    request_deserializer=avikom_dot_nlp_dot_answer__question__service__pb2.AnswerQuestionQuery.FromString,
                    response_serializer=avikom_dot_nlp_dot_answer__question__service__pb2.AnswerQuestionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.nlp.AnswerQuestionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AnswerQuestionService(object):
    """*
    This service sends a question and context as requests to the nlp module (currently HuggingFace).
    For example, you might want to extract information from a text by asking a question. You assume, that 
    the answer to your question can be found within the text.
    @author: Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

    @staticmethod
    def AnswerQuestion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.nlp.AnswerQuestionService/AnswerQuestion',
            avikom_dot_nlp_dot_answer__question__service__pb2.AnswerQuestionQuery.SerializeToString,
            avikom_dot_nlp_dot_answer__question__service__pb2.AnswerQuestionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class TargetRequest(google.protobuf.message.Message):
    """*
    This message is used to request an entities location.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_FIELD_NUMBER: builtins.int
    SLEEP_MS_FIELD_NUMBER: builtins.int
    WATCHER_FIELD_NUMBER: builtins.int
    target: builtins.str
    """/ the object/entity that should be tracked"""
    sleep_ms: builtins.int
    """/ the sleep interval between messages; should be equal or larger than time needed to process messages; a higher value reduces load on the service and on the network"""
    watcher: builtins.str
    """/ the origin of relative requests"""
    def __init__(
        self,
        *,
        target: builtins.str = ...,
        sleep_ms: builtins.int = ...,
        watcher: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sleep_ms", b"sleep_ms", "target", b"target", "watcher", b"watcher"]) -> None: ...

global___TargetRequest = TargetRequest



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _CameraState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CameraStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CameraState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNALLOCATED: _CameraState.ValueType  # 0
    """/ camera is not allocated or the state is unknown"""
    VUFORIA: _CameraState.ValueType  # 1
    """/ camera is used for image target tracking by Vuforia"""
    WEB_RTC: _CameraState.ValueType  # 2
    """/ camera is used by remote communication with WebRTC"""
    SPECTATOR_VIEW: _CameraState.ValueType  # 3
    """/ camera is used by the spectator view to track the QR code for device coupling"""

class CameraState(_CameraState, metaclass=_CameraStateEnumTypeWrapper):
    """*
    This message represents the camera state mostly associated with Unity as only one service may use the system's camera at a time.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

UNALLOCATED: CameraState.ValueType  # 0
"""/ camera is not allocated or the state is unknown"""
VUFORIA: CameraState.ValueType  # 1
"""/ camera is used for image target tracking by Vuforia"""
WEB_RTC: CameraState.ValueType  # 2
"""/ camera is used by remote communication with WebRTC"""
SPECTATOR_VIEW: CameraState.ValueType  # 3
"""/ camera is used by the spectator view to track the QR code for device coupling"""
global___CameraState = CameraState

class _CameraTrigger:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CameraTriggerEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CameraTrigger.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RELEASE: _CameraTrigger.ValueType  # 0
    """/ release the camera"""
    ACQUIRE_VUFORIA: _CameraTrigger.ValueType  # 1
    """/ request acquisition for image target tracking"""
    ACQUIRE_WEB_RTC: _CameraTrigger.ValueType  # 2
    """/ request acquisition for remote communication"""
    ACQUIRE_SPECTATOR_VIEW: _CameraTrigger.ValueType  # 3
    """/ request acquisition for spectator view coupling"""

class CameraTrigger(_CameraTrigger, metaclass=_CameraTriggerEnumTypeWrapper):
    """*
    This message represents the EVENT or REQUEST to acquire the camera.
    Whether the camera can be acquired depends on its current state. 
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

RELEASE: CameraTrigger.ValueType  # 0
"""/ release the camera"""
ACQUIRE_VUFORIA: CameraTrigger.ValueType  # 1
"""/ request acquisition for image target tracking"""
ACQUIRE_WEB_RTC: CameraTrigger.ValueType  # 2
"""/ request acquisition for remote communication"""
ACQUIRE_SPECTATOR_VIEW: CameraTrigger.ValueType  # 3
"""/ request acquisition for spectator view coupling"""
global___CameraTrigger = CameraTrigger



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.vision.image_info_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Image(google.protobuf.message.Message):
    """*
    This message represents a (chunk of an) image. It may contain an `ImageInfo` header or a chunk of data of an image.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> avikom.vision.image_info_pb2.ImageInfo:
        """/ an information header defining size, dimensions and transfer parameters"""
    data: builtins.bytes
    """/ a series of bytes (size defined by `chunk_size` in `info`) representing a chunk of an image"""
    def __init__(
        self,
        *,
        info: avikom.vision.image_info_pb2.ImageInfo | None = ...,
        data: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "info", b"info"]) -> None: ...

global___Image = Image



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/scene_consumer_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import scene_pb2 as avikom_dot_assistance_dot_scene__pb2
from avikom.assistance import task_pb2 as avikom_dot_assistance_dot_task__pb2
from avikom.assistance import task_step_pb2 as avikom_dot_assistance_dot_task__step__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.avikom/assistance/scene_consumer_service.proto\x12\x11\x61vikom.assistance\x1a\x1d\x61vikom/assistance/scene.proto\x1a\x1c\x61vikom/assistance/task.proto\x1a!avikom/assistance/task_step.proto\x1a\x1b\x61vikom/generic/result.proto\x1a\x1bgoogle/protobuf/empty.proto2\xd4\x01\n\x14SceneConsumerService\x12>\n\x08SetScene\x12\x18.avikom.assistance.Scene\x1a\x16.avikom.generic.Result\"\x00\x12>\n\x08GetScene\x12\x16.google.protobuf.Empty\x1a\x18.avikom.assistance.Scene\"\x00\x12<\n\x07SetTask\x12\x17.avikom.assistance.Task\x1a\x16.avikom.generic.Result\"\x00\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.scene_consumer_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _SCENECONSUMERSERVICE._serialized_start=224
  _SCENECONSUMERSERVICE._serialized_end=436
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class StepProficiencyQuery(google.protobuf.message.Message):
    """
    A query to retrieve `StepProficiencies` for task steps or `SplitProcedureResults` for taks
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    TARGET_NAME_FIELD_NUMBER: builtins.int
    user_id: builtins.int
    """/ ID of the user in question"""
    target_name: builtins.str
    """/ either a task step name (for proficiencies) or a task name (for split procedure results)"""
    def __init__(
        self,
        *,
        user_id: builtins.int = ...,
        target_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["target_name", b"target_name", "user_id", b"user_id"]) -> None: ...

global___StepProficiencyQuery = StepProficiencyQuery



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.assistance import service_provider_service_pb2 as avikom_dot_assistance_dot_service__provider__service__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2


class ServiceProviderServiceStub(object):
    """*
    A service is a task step-agnostic solution provider.
    It must be specifically requested/configured in the apprpriate task step.
    @author Alexander McService Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.PostServiceRequest = channel.unary_unary(
                '/avikom.assistance.ServiceProviderService/PostServiceRequest',
                request_serializer=avikom_dot_assistance_dot_service__provider__service__pb2.ServiceRequest.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.CancelServiceRequest = channel.unary_unary(
                '/avikom.assistance.ServiceProviderService/CancelServiceRequest',
                request_serializer=avikom_dot_assistance_dot_service__provider__service__pb2.ServiceRequest.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )


class ServiceProviderServiceServicer(object):
    """*
    A service is a task step-agnostic solution provider.
    It must be specifically requested/configured in the apprpriate task step.
    @author Alexander McService Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def PostServiceRequest(self, request, context):
        """/ starts the service; a task_id must be passed for the service to resolve it
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelServiceRequest(self, request, context):
        """/ cancels a currently running task request; task_id must be provided
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ServiceProviderServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'PostServiceRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.PostServiceRequest,
                    request_deserializer=avikom_dot_assistance_dot_service__provider__service__pb2.ServiceRequest.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'CancelServiceRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelServiceRequest,
                    request_deserializer=avikom_dot_assistance_dot_service__provider__service__pb2.ServiceRequest.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.assistance.ServiceProviderService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ServiceProviderService(object):
    """*
    A service is a task step-agnostic solution provider.
    It must be specifically requested/configured in the apprpriate task step.
    @author Alexander McService Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    @staticmethod
    def PostServiceRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.ServiceProviderService/PostServiceRequest',
            avikom_dot_assistance_dot_service__provider__service__pb2.ServiceRequest.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelServiceRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.ServiceProviderService/CancelServiceRequest',
            avikom_dot_assistance_dot_service__provider__service__pb2.ServiceRequest.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ValueType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ValueTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ValueType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TYPE_UNSET: _ValueType.ValueType  # 0
    """/ default value; should not be used in actual messages"""
    TYPE_STRING: _ValueType.ValueType  # 1
    """/ variable is a string"""
    TYPE_NUMBER: _ValueType.ValueType  # 2
    """/ variable is a (JavaScript) number"""
    TYPE_BOOLEAN: _ValueType.ValueType  # 3
    """/ variable is a boolean value"""

class ValueType(_ValueType, metaclass=_ValueTypeEnumTypeWrapper):
    """*
    This enum represents a variable type of Camunda variables.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

TYPE_UNSET: ValueType.ValueType  # 0
"""/ default value; should not be used in actual messages"""
TYPE_STRING: ValueType.ValueType  # 1
"""/ variable is a string"""
TYPE_NUMBER: ValueType.ValueType  # 2
"""/ variable is a (JavaScript) number"""
TYPE_BOOLEAN: ValueType.ValueType  # 3
"""/ variable is a boolean value"""
global___ValueType = ValueType

@typing_extensions.final
class Variable(google.protobuf.message.Message):
    """*
    This message describes a Camunda variable.
    Values of commonly stored as a string and are parsed according to the type mentioned in `type` when needed.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_TYPE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """/ name of the variable"""
    value_type: global___ValueType.ValueType
    """/ variable type"""
    value: builtins.str
    """/ string-encoded variable value"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value_type: global___ValueType.ValueType = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "value", b"value", "value_type", b"value_type"]) -> None: ...

global___Variable = Variable



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.assistance import runtime_step_list_pb2 as avikom_dot_assistance_dot_runtime__step__list__pb2
from avikom.assistance import runtime_step_state_change_pb2 as avikom_dot_assistance_dot_runtime__step__state__change__pb2
from avikom.generic import peer_pb2 as avikom_dot_generic_dot_peer__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class RuntimeStepConsumerServiceStub(object):
    """*
    A runtime step consumer is interested in runtime step information. If scene and task information are
    required, peers should provide `SceneConsumerProvider` as well.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetRuntimeSteps = channel.unary_unary(
                '/avikom.assistance.RuntimeStepConsumerService/SetRuntimeSteps',
                request_serializer=avikom_dot_assistance_dot_runtime__step__list__pb2.RuntimeStepList.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.UpdateRuntimeStep = channel.unary_unary(
                '/avikom.assistance.RuntimeStepConsumerService/UpdateRuntimeStep',
                request_serializer=avikom_dot_assistance_dot_runtime__step__state__change__pb2.RuntimeStepStateChange.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.SetPeers = channel.unary_unary(
                '/avikom.assistance.RuntimeStepConsumerService/SetPeers',
                request_serializer=avikom_dot_generic_dot_peer__pb2.PeerList.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )


class RuntimeStepConsumerServiceServicer(object):
    """*
    A runtime step consumer is interested in runtime step information. If scene and task information are
    required, peers should provide `SceneConsumerProvider` as well.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def SetRuntimeSteps(self, request, context):
        """/ Updates the currently eligible task steps.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateRuntimeStep(self, request, context):
        """/ When a `RuntimeTaskStep` changes its state, consumers will be informed via this call.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetPeers(self, request, context):
        """/ When peer information changes while a step is conducted, this method should be used to inform consumers. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RuntimeStepConsumerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetRuntimeSteps': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRuntimeSteps,
                    request_deserializer=avikom_dot_assistance_dot_runtime__step__list__pb2.RuntimeStepList.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'UpdateRuntimeStep': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateRuntimeStep,
                    request_deserializer=avikom_dot_assistance_dot_runtime__step__state__change__pb2.RuntimeStepStateChange.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'SetPeers': grpc.unary_unary_rpc_method_handler(
                    servicer.SetPeers,
                    request_deserializer=avikom_dot_generic_dot_peer__pb2.PeerList.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.assistance.RuntimeStepConsumerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RuntimeStepConsumerService(object):
    """*
    A runtime step consumer is interested in runtime step information. If scene and task information are
    required, peers should provide `SceneConsumerProvider` as well.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    @staticmethod
    def SetRuntimeSteps(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.RuntimeStepConsumerService/SetRuntimeSteps',
            avikom_dot_assistance_dot_runtime__step__list__pb2.RuntimeStepList.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateRuntimeStep(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.RuntimeStepConsumerService/UpdateRuntimeStep',
            avikom_dot_assistance_dot_runtime__step__state__change__pb2.RuntimeStepStateChange.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetPeers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.RuntimeStepConsumerService/SetPeers',
            avikom_dot_generic_dot_peer__pb2.PeerList.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _InteractionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _InteractionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_InteractionType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INTERACTION_UNKNOWN: _InteractionType.ValueType  # 0
    """/ default value; should not be set actively"""
    INTERACTION_TAP: _InteractionType.ValueType  # 1
    """/ a user taps/clicks an element"""
    INTERACTION_HOME: _InteractionType.ValueType  # 2
    """/ a home menu button or return element is activated"""
    INTERACTION_BUTTON_DOWN: _InteractionType.ValueType  # 3
    """/ a button is pushed down"""
    INTERACTION_BUTTON_UP: _InteractionType.ValueType  # 4
    """/ a button is released"""
    INTERACTION_DRAG_START: _InteractionType.ValueType  # 5
    """/ user starts to drag an element"""
    INTERACTION_DRAG_STOP: _InteractionType.ValueType  # 6
    """/ user finished the dragging process"""

class InteractionType(_InteractionType, metaclass=_InteractionTypeEnumTypeWrapper):
    """*
    This enum contains all currently available kinds of interaction users can conduct with their surounding.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

INTERACTION_UNKNOWN: InteractionType.ValueType  # 0
"""/ default value; should not be set actively"""
INTERACTION_TAP: InteractionType.ValueType  # 1
"""/ a user taps/clicks an element"""
INTERACTION_HOME: InteractionType.ValueType  # 2
"""/ a home menu button or return element is activated"""
INTERACTION_BUTTON_DOWN: InteractionType.ValueType  # 3
"""/ a button is pushed down"""
INTERACTION_BUTTON_UP: InteractionType.ValueType  # 4
"""/ a button is released"""
INTERACTION_DRAG_START: InteractionType.ValueType  # 5
"""/ user starts to drag an element"""
INTERACTION_DRAG_STOP: InteractionType.ValueType  # 6
"""/ user finished the dragging process"""
global___InteractionType = InteractionType
